@@ -1,17 +1,16 @@
 # -*- coding: utf-8 -*-
-from .base import Database
 from .db_url import parse_url_to_dict
-from .mysql import MysqlDatabase
-from .sqlite import SqliteDatabase
-
+from .base import DatabaseProxy
+from .mysql import MysqlDatabaseProxy
+from .sqlite import SqliteDatabaseProxy
 
 schemes = {
-    'mysql': MysqlDatabase,
-    'sqlite': SqliteDatabase,
+    'mysql': MysqlDatabaseProxy,
+    'sqlite': SqliteDatabaseProxy,
 }
 
 
-def connect(db_url) -> Database:
+def connect(db_url) -> DatabaseProxy:
     config = parse_url_to_dict(db_url=db_url)
     scheme = config.pop('scheme')
 
